@@ -4,16 +4,18 @@ use strict;
 package Devel::hdb;
 
 use Devel::hdb::App;
-use Devel::hdb::DB;
+use Devel::hdb::TraceFollow;
 use IO::Socket::INET;
 use IO::File;
 
-our $VERSION = 0.08_01;
+our $VERSION = '0.23_02';
 
 sub import {
     my $class = shift;
 
     our $TESTHARNESS;
+    my($trace, $follow);
+
     while (@_) {
         my $param = shift;
         if ($param =~ m/port:(\d+)/) {
@@ -25,19 +27,28 @@ sub import {
         } elsif ($param eq 'testharness') {
             $TESTHARNESS = 1;
         } elsif ($param =~ m/trace:(.*)/) {
-            print STDERR "Writing execution trace to $1...\n" unless $TESTHARNESS;
-            DB->disable_stopping(1);
-            unless($DB::trace = IO::File->new($1, 'w')) {
-                die "Can't open trace file for writing: $!";
-            }
+            $trace = $1;
         } elsif ($param =~ m/follow:(.*)/) {
-            DB->input_trace_file($1, sub { Devel::hdb::App->get()->notify_trace_diff(@_) });
+            $follow = $1;
         } elsif ($param =~ m/listenfd:(\d+)/) {
             our $LISTEN_SOCK = IO::Socket::INET->new();
             $LISTEN_SOCK->fdopen($1, 'r');
         }
 
     }
+
+    my $self = Devel::hdb::App->get();
+    if ($trace) {
+        print STDERR "Writing execution trace to $trace...\n" unless $TESTHARNESS;
+        $self->{trace} = Devel::hdb::Trace->new($trace);
+    } elsif ($follow) {
+        $self->{follow} = Devel::hdb::Follow->new(
+                            $follow,
+                            sub { $self->notify_trace_diff(@_) }
+                        );
+    }
+
+    $self->attach();
 }
 1;
 __END__
@@ -61,7 +72,7 @@ To debug a Perl program, start it like this:
     perl -d:hdb youprogram.pl
 
 It will print a message on STDERR with the URL the debugger is listening to.
-Point your web browser at this URL and it will being up the debugger GUI.
+Point your web browser at this URL and it will bring up the debugger GUI.
 It defaults to listening on localhost port 8080; to use a different port,
 start it like this:
 
@@ -132,20 +143,33 @@ are blue.  Lines with actions have a circle outline, and are dimmed when the
 breakpoint is inactive.
 
 The banner at the top of the Code Pane shows the current function and its
-arguments.  Clicking on the banner will scoll the Code Pane to show the
+arguments.  Clicking on the banner will scroll the Code Pane to show the
 currently executing line.
 
 Hover the mouse over a variable to see its value.  It shows the value in
 whichever stack frame is being displayed.  To see the values for variables
 in higher frames, select the appropriate frame from the tab on the left.
+Right-click on a variable to add it to the list of watch expressions on the
+right.
 
 =head3 Watch Expressions
 
 The right side of the GUI shows watch expressions.  To add a new expression to
-the watch window, click on the "+".  To remove a watched expression, click on
-the "x" next to its name.  Composite types like Hashes and arrays have a blue
-circled number indicating how many elements belong to it.  To collapse/expand
-them, click the blue cicle.
+the watch window, click on the "+" or right-click on a variable in a code pane.
+To remove a watched expression, click on the "x" next to its name.  Composite
+types like hashes and arrays have a blue circled number indicating how many
+elements belong to it.  To collapse/expand them, click the blue circle.
+
+A watched typeglob will show all the used slots within the glob.  Older
+versions of perl will always create an undefined value in the SCALAR slot.
+The value for the IO slot will be the file descriptor number of the
+filehandle and its position as reported by sysseek(), or undef if it is closed.
+
+Enabling the checkbox next to the expression turns it into a watchpoint.
+Watchpoints are evaluated in list context, and if their value changes, the
+debugged program will stop.  For list values, it is considered changed if any
+of the elements changes value or if the number of values in the list changes.
+It will not perform a deep search for changed values.
 
 =head3 Key bindings
 
@@ -154,49 +178,27 @@ command-line debugger commands
 
 =over 4
 
-=item s
+=item s - Step in
 
-Step in
+=item n - Step over
 
-=item n
+=item <CR> - Repeat the last 's' or 'n'
 
-Step over
+=item r - Step out
 
-=item <CR>
+=item c - Continue/Run
 
-Repeat the last 's' or 'n'
+=item q - Quit/Exit
 
-=item r
+=item x - Add new watch expression
 
-Step out
+=item f - Add new file
 
-=item c
+=item . - Scroll the code window to show the current line
 
-Continue/Run
+=item L - Open the breakpoint manager
 
-=item q
-
-Quit/Exit
-
-=item x
-
-Add new watch expression
-
-=item f
-
-Add new file
-
-=item .
-
-Scroll the code window to show the current line
-
-=item L
-
-Open the breakpoint manager
-
-=item b
-
-Toggle a breakpoint on the current line
+=item b - Toggle a breakpoint on the current line
 
 =back
 
@@ -209,9 +211,11 @@ debugger window, it will pop up a dialog with two options
 =over
 
 =item Open
+
 Open a new browser window and debug the child process inside it
 
 =item Detach
+
 Disables the debugger in the child process, and forces it to run to completion.
 
 =back
@@ -243,26 +247,26 @@ This package includes these third party libraries:
 
 =over
 
-=item *
-jQuery version 1.7.2 L<http://jquery.com/>
+=item * jQuery version 2.1.1 L<http://jquery.com/>
 
-=item *
-scrollTo jQuery plugin version 1.4.3.1 L<http://flesler.blogspot.com/2007/10/jqueryscrollto.html>
+=item * scrollTo jQuery plugin version 1.4.3.1 L<http://flesler.blogspot.com/2007/10/jqueryscrollto.html>
 
-=item *
-Twitter Bootstrap version 2.3.0 L<http://twitter.github.com/bootstrap/index.html>
+=item * Twitter Bootstrap version 2.3.0 L<http://twitter.github.com/bootstrap/index.html>
 
-=item *
-Handlebars version 1.0rc2 L<http://handlebarsjs.com/>
+=item * Handlebars version 2.0.0 L<http://handlebarsjs.com/>
 
 =back
 
+=head1 SEE ALSO
+
+L<Devel::Chitin>, L<DB>, L<perldebguts>
+
 =head1 AUTHOR
 
 Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2013, Anthony Brummett.  This module is free software. It may
+Copyright 2014, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
 
