@@ -3,37 +3,26 @@ package Devel::hdb::Router;
 use strict;
 use warnings;
 
+our $VERSION = '0.23_02';
+
 sub new {
     my $class = shift;
     return bless {}, $class;
 }
 
-sub get($$&) {
-    my($self, $path, $sub) = @_;
-
-    $self->{GET} ||= [];
-    push @{ $self->{GET}}, [$path, $sub];
-}
-
-sub post($$&) {
-    my($self, $path, $sub) = @_;
-
-    $self->{POST} ||= [];
-    push @{ $self->{POST}}, [$path, $sub];
-}
-
-sub put($$&) {
-    my($self, $path, $sub) = @_;
-
-    $self->{PUT} ||= [];
-    push @{ $self->{PUT}}, [$path, $sub];
-}
-
-sub delete($$&) {
-    my($self, $path, $sub) = @_;
-
-    $self->{DELETE} ||= [];
-    push @{ $self->{DELETE}}, [$path, $sub];
+foreach my $method ( qw(get post put delete head) ) {
+    my $key = uc($method);
+    my $sub = qq(
+        sub {
+            my(\$self, \$path, \$sub) = \@_;
+            my \$list = \$self->{$key} ||= [];
+            #print STDERR "Registering route for \$key \$path\\n";
+            push \@\$list, [ \$path, \$sub ];
+        };
+    );
+    $sub =~ s/#// if $ENV{HDB_DEBUG_MSG};
+    no strict 'refs';
+    *$method = eval $sub;
 }
 
 sub route($$) {
@@ -41,6 +30,7 @@ sub route($$) {
     my $env = shift;
 
     my $req_method = $env->{REQUEST_METHOD};
+    print STDERR "Incoming request: $req_method ",$env->{PATH_INFO},"\n" if ($ENV{HDB_DEBUG_MSG});
     return unless exists $self->{$req_method};
     my $matchlist = $self->{$req_method};
 
@@ -59,6 +49,7 @@ sub route($$) {
         }
 
         if ($fire) {
+            print STDERR "  matched!\n" if ($ENV{HDB_DEBUG_MSG});
             my $rv = $cb->($env, @matches);
             my $hooks = $self->{after_hooks}->{$req_method}->{$path};
             if ($hooks && @$hooks) {
@@ -67,6 +58,7 @@ sub route($$) {
             return $rv;
         }
     }
+    print STDERR "  no matching route\n" if ($ENV{HDB_DEBUG_MSG});
     return [ 404, [ 'Content-Type' => 'text/html'], ['Not found']];
 }
 
